"""Use JSONB for Postgres

Revision ID: 389227821116
Revises: b235e2d83156
Create Date: 2025-02-11 13:00:13.397414+00:00

"""

from collections.abc import Sequence

import sqlalchemy as sa
from alembic import op
from sqlalchemy.dialects import postgresql

import dnscheck

# revision identifiers, used by Alembic.
revision: str = "389227821116"
down_revision: str | None = "b235e2d83156"
branch_labels: str | Sequence[str] | None = None
depends_on: str | Sequence[str] | None = None


def upgrade() -> None:
    with op.batch_alter_table("dnscheck_domain_check") as batch_op:
        batch_op.alter_column(
            "ds_info",
            existing_type=postgresql.JSON(astext_type=sa.Text()),
            type_=dnscheck.db.common.JSONType(),
            existing_nullable=True,
        )
        batch_op.alter_column(
            "results",
            existing_type=postgresql.JSON(astext_type=sa.Text()),
            type_=dnscheck.db.common.JSONType(),
            existing_nullable=True,
        )
        batch_op.alter_column(
            "summary",
            existing_type=postgresql.JSON(astext_type=sa.Text()),
            type_=dnscheck.db.common.JSONType(),
            existing_nullable=True,
        )
    with op.batch_alter_table("dnscheck_nsset_check") as batch_op:
        batch_op.alter_column(
            "nameservers",
            existing_type=postgresql.JSON(astext_type=sa.Text()),
            type_=dnscheck.db.common.JSONType(),
            existing_nullable=False,
        )


def downgrade() -> None:
    with op.batch_alter_table("dnscheck_nsset_check") as batch_op:
        batch_op.alter_column(
            "nameservers",
            existing_type=dnscheck.db.common.JSONType(),
            type_=postgresql.JSON(astext_type=sa.Text()),
            existing_nullable=False,
        )
    with op.batch_alter_table("dnscheck_domain_check") as batch_op:
        batch_op.alter_column(
            "summary",
            existing_type=dnscheck.db.common.JSONType(),
            type_=postgresql.JSON(astext_type=sa.Text()),
            existing_nullable=True,
        )
        batch_op.alter_column(
            "results",
            existing_type=dnscheck.db.common.JSONType(),
            type_=postgresql.JSON(astext_type=sa.Text()),
            existing_nullable=True,
        )
        batch_op.alter_column(
            "ds_info",
            existing_type=dnscheck.db.common.JSONType(),
            type_=postgresql.JSON(astext_type=sa.Text()),
            existing_nullable=True,
        )
